# eric7.Plugins.VcsPlugins.vcsMercurial.HgBookmarksInOutDialog

Module implementing a dialog to show a list of incoming or outgoing bookmarks.

### Global Attributes

None

### Classes

HgBookmarksInOutDialog | Class implementing a dialog to show a list of incoming or outgoing bookmarks.

### Functions

None

## HgBookmarksInOutDialog

Class implementing a dialog to show a list of incoming or outgoing bookmarks.

### Derived from

QDialog, Ui_HgBookmarksInOutDialog

### Class Attributes

INCOMING
OUTGOING

### Class Methods

None

### Methods

HgBookmarksInOutDialog | Constructor
__finish | Private slot called when the process finished or the user pressed the button.
__generateItem | Private method to generate a bookmark item in the bookmarks list.
__processOutputLine | Private method to process the lines of output.
__resizeColumns | Private method to resize the list columns.
__resort | Private method to resort the tree.
__showError | Private slot to show some error.
closeEvent | Protected slot implementing a close event handler.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
start | Public slot to start the bookmarks command.

### Static Methods

None

#### HgBookmarksInOutDialog (Constructor)

HgBookmarksInOutDialog(vcs, mode, parent=None)

Constructor

vcs
  reference to the vcs object
mode
  mode of the dialog (HgBookmarksInOutDialog.INCOMING, HgBookmarksInOutDialog.OUTGOING)
parent
  reference to the parent widget (QWidget)

Raises ValueError:
  raised to indicate an invalid dialog mode

#### HgBookmarksInOutDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### HgBookmarksInOutDialog.__generateItem

__generateItem(changeset, name)

Private method to generate a bookmark item in the bookmarks list.

changeset
  changeset of the bookmark (string)
name
  name of the bookmark (string)

#### HgBookmarksInOutDialog.__processOutputLine

__processOutputLine(line)

Private method to process the lines of output.

line
  output line to be processed (string)

#### HgBookmarksInOutDialog.__resizeColumns

__resizeColumns()

Private method to resize the list columns.

#### HgBookmarksInOutDialog.__resort

__resort()

Private method to resort the tree.

#### HgBookmarksInOutDialog.__showError

__showError(out)

Private slot to show some error.

out
  error to be shown (string)

#### HgBookmarksInOutDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e
  close event (QCloseEvent)

#### HgBookmarksInOutDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### HgBookmarksInOutDialog.start

start()

Public slot to start the bookmarks command.

Raises ValueError:
  raised to indicate an invalid dialog mode

Up